package pack

import (
	"youngee_m_api/consts"
	"youngee_m_api/model/common_model"
	"youngee_m_api/model/gorm_model"
	"youngee_m_api/model/http_model"
	"youngee_m_api/util"

	"github.com/caixw/lib.go/conv"
)

func HttpPricingRequestToConditions(req *http_model.SearchPricingRequest) *common_model.PricingConditions {
	pricingUpdated := conv.MustString(req.UpdateAt, "")
	return &common_model.PricingConditions{
		ProjectType: conv.MustInt64(req.ProjectType, 0),
		FeeForm:     conv.MustInt64(req.FeeForm, 0),
		Platform:    conv.MustInt64(req.Platform, 0),
		UpdateAt:    pricingUpdated,
	}
}

func GormSearchPricingDataToHttpData(gormPricings []*gorm_model.InfoPricingStrategy) []*http_model.SearchPricingPreview {
	var httpPricingPreviews []*http_model.SearchPricingPreview
	for _, gormPricing := range gormPricings {
		httpPricingPreview := MGromSearchPricingDataToHttpData(gormPricing)
		httpPricingPreviews = append(httpPricingPreviews, httpPricingPreview)
	}
	return httpPricingPreviews
}

func MGromSearchPricingDataToHttpData(gormPricing *gorm_model.InfoPricingStrategy) *http_model.SearchPricingPreview {
	updatedTime := conv.MustString(gormPricing.UpdateAt, "")
	updatedTime = updatedTime[0:19]
	fans := ""
	if gormPricing.FansLow == 0 && gormPricing.FansUp == 0 {
		fans = "不限"
	} else if gormPricing.FansLow == 0 && gormPricing.FansUp != 0 {
		fans = util.GetNumString(gormPricing.FansUp) + "以下"
	} else if gormPricing.FansLow != 0 && gormPricing.FansUp != 0 {
		fans = util.GetNumString(gormPricing.FansLow) + "-" + util.GetNumString(gormPricing.FansUp)
	} else if gormPricing.FansLow != 0 && gormPricing.FansUp == 0 {
		fans = util.GetNumString(gormPricing.FansLow) + "以上"
	}
	serviceCharge := ""
	if gormPricing.ServiceCharge == 0 {
		serviceCharge = "不限"
	} else {
		serviceCharge = conv.MustString(gormPricing.ServiceCharge, "")
	}
	return &http_model.SearchPricingPreview{
		ID:             conv.MustString(gormPricing.ID, ""),
		StrategyId:     gormPricing.StrategyId,
		ProjectType:    consts.GetProjectType(gormPricing.ProjectType),
		Platform:       consts.GetProjectPlatform(gormPricing.Platform),
		ManuscriptForm: consts.GetFeeForm(gormPricing.FeeForm),
		Fans:           fans,
		ServiceCharge:  serviceCharge,
		ServiceRate:    conv.MustString(gormPricing.ServiceRate/10, "") + "%",
		UpdateTime:     updatedTime,
	}
}

func HttpBreachHandledRequestToConditions(request *http_model.BreachHandledRequest) *common_model.BreachHandledConditions {
	return &common_model.BreachHandledConditions{
		HandleResult:    conv.MustInt32(request.HandleResult, 0),
		TerminateReason: conv.MustInt32(request.TerminateReason, 0),
	}
}
